package VMOMI::HostVmfsVolumeUnmapPriority;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
